from argparse import ArgumentParser
from collections import defaultdict
from pathlib import Path

from parser import parse_mother_request


def _get_parser() -> ArgumentParser:
    parser = ArgumentParser()
    parser.add_argument(
        "path",
        help="Path for mother request",
        type=str,
    )
    return parser


def get_variables(path: Path | str, must_match: bool):
    df = parse_mother_request(path)
    df = df[["Application", "Request No.", "gsv_param", "opa_variable"]]
    variables = defaultdict(list)
    for _, row in df.iterrows():
        gsv = row["gsv_param"]
        opa = row["opa_variable"]
        app = row["Application"]
        if gsv == opa:
            variables[gsv].append(app)
        else:
            if must_match:
                raise ValueError(
                    "GSV and OPA request have non-matching variables: "
                    f"'{row['gsv_param']}' and '{row['opa_variable']}'."
                )
            variables[gsv].append(app)
            variables[opa].append(app)
    return dict(variables)


if __name__ == "__main__":
    args = _get_parser().parse_args()
    path = Path(args.path)
    variables = get_variables(path, must_match=True)
